@@ -54,8 +54,10 @@ def checkout_branch(project, issue):
         ).lower(),
     )
 
+    default_parent_branch_name = git.current_branch_name(project)
+
     parent_branch_name = prompt_utils.ask_questions_input(
-        "Inserisci branch iniziale: ", "master"
+        "Inserisci branch iniziale: ", default_parent_branch_name
     )
 
     branch_type = issue["Type"].lower().replace(" ", "-")
