@@ -120,7 +120,4 @@ def twigify(projects_list):
             "default_branch": False,
         }
 
-    return f'"{yaml.dump(projects_dict, explicit_start=True, default_flow_style=False)}"'  # necessario per fare l'escape corretto
-
-    # development only
-    # return json.dumps(projects_dict) chiamando twig da file non bisogna dumpare due volte
+    return yaml.dump(projects_dict, explicit_start=True, default_flow_style=False)
