@@ -30,68 +30,53 @@ def entrypoint(project, timeout):
     git.fetch(project)
     repo = github.get_repo(project)
 
-    latest_release = get_release(repo)
+    tags = repo.get_tags()
+    tag = git.get_last_tag_number(tags)
+    latest_release = get_release(repo, tag)
 
-    versions = bump_versions(latest_release.title)
+    current_version = latest_release.tag_name if latest_release else tag
 
-    commits = github.get_commits_since_release(repo, latest_release)
+    if current_version:
+        logger.info(f"La release attuale è {current_version}")
+        versions = bump_versions(current_version)
+        commits = github.get_commits_since_release(repo, current_version)
 
-    check_migrations_deploy(commits)
+        check_migrations_deploy(commits)
 
-    message = "\n".join(["* " + c.commit.message.splitlines()[0] for c in commits])
+        message = "\n".join(["* " + c.commit.message.splitlines()[0] for c in commits])
 
-    logger.info(f"\nLista dei commit:\n{message}\n")
+        logger.info(f"\nLista dei commit:\n{message}\n")
 
-    if not prompt_utils.ask_confirm("Vuoi continuare?"):
-        sys.exit(-1)
+        if not prompt_utils.ask_confirm("Vuoi continuare?"):
+            sys.exit()
 
-    new_version = prompt_utils.ask_choices(
-        "Seleziona versione:",
-        [
-            {"name": f"Patch {versions['patch']}", "value": versions["patch"]},
-            {"name": f"Minor {versions['minor']}", "value": versions["minor"]},
-            {"name": f"Major {versions['major']}", "value": versions["major"]},
-        ],
-    )
-
-    release_state = config.load()["youtrack"]["release_state"]
-
-    issue_ids = youtrack.get_issue_ids(commits)
-
-    if len(issue_ids) > 0:
-        update_youtrack_state = prompt_utils.ask_confirm(
-            f"Vuoi spostare le card associate in {release_state}?", default=False
+        new_version = prompt_utils.ask_choices(
+            "Seleziona versione:",
+            [
+                {"name": f"Patch {versions['patch']}", "value": versions["patch"]},
+                {"name": f"Minor {versions['minor']}", "value": versions["minor"]},
+                {"name": f"Major {versions['major']}", "value": versions["major"]},
+            ],
         )
 
-        for issue_id in issue_ids:
-            try:
-                youtrack.comment(
-                    issue_id,
-                    f"Deploy in produzione di {project} effettuato con la release {new_version}",
-                )
-                if update_youtrack_state:
-                    youtrack.update_state(issue_id, release_state)
-                    logger.info(f"{issue_id} spostata in {release_state}")
-            except Exception:
-                logger.warning(
-                    f"Si è verificato un errore durante lo spostamento della card {issue_id} in {release_state}"
-                )
+        manage_youtrack_card(project, commits, new_version)
+    else:
+        # Se non viene trovata la release e non ci sono tag, viene saltato il check delle migrations e l'update delle card su youtrack
+        logger.warning("Nessun tag trovato, sto per pubblicare il tag 0.1.0")
+        if not prompt_utils.ask_confirm("Sicuro di voler continuare?", default=False):
+            sys.exit()
+        new_version = "0.1.0"
+        message = f"First release with tag {new_version}"
 
     create_release(repo, new_version, message, project)
 
 
-def get_release(repo):
+def get_release(repo, tag):
     with Halo(text="Loading...", spinner="dots", color="magenta"):
         latest_release = github.get_latest_release_if_exists(repo)
-        tags = repo.get_tags()
-        tag = git.get_last_tag_number(tags)
     if latest_release and latest_release.title == tag:
-        logger.info(f"La release attuale è {latest_release.title}")
         return latest_release
-    logger.info(f"L'ultimo tag trovato è {tag}")
-    if not prompt_utils.ask_confirm("Sicuro di voler continuare?"):
-        sys.exit(-1)
-    return repo.create_git_release(tag, tag, f"New release from tag {tag}")
+    return None
 
 
 def create_release(repo, new_version, message, project):
@@ -133,8 +118,8 @@ def check_migrations_deploy(commits):
         )
     if git.migrations_found(files_changed):
         logger.warning("ATTENZIONE: migrations rilevate nel codice")
-        if not prompt_utils.ask_confirm("Sicuro di voler continuare?"):
-            sys.exit(-1)
+        if not prompt_utils.ask_confirm("Sicuro di voler continuare?", default=False):
+            sys.exit()
 
 
 def stop_if_prod_locked(project, lock):
@@ -150,3 +135,28 @@ def stop_if_prod_locked(project, lock):
             f"Il progetto è lockato in produzione da {request_object['by']}. Impossibile continuare."
         )
         sys.exit(-1)
+
+
+def manage_youtrack_card(project, commits, new_version):
+    release_state = config.load()["youtrack"]["release_state"]
+
+    issue_ids = youtrack.get_issue_ids(commits)
+
+    if len(issue_ids) > 0:
+        update_youtrack_state = prompt_utils.ask_confirm(
+            f"Vuoi spostare le card associate in {release_state}?", default=False
+        )
+
+        for issue_id in issue_ids:
+            try:
+                youtrack.comment(
+                    issue_id,
+                    f"Deploy in produzione di {project} effettuato con la release {new_version}",
+                )
+                if update_youtrack_state:
+                    youtrack.update_state(issue_id, release_state)
+                    logger.info(f"{issue_id} spostata in {release_state}")
+            except Exception:
+                logger.warning(
+                    f"Si è verificato un errore durante lo spostamento della card {issue_id} in {release_state}"
+                )
