@@ -34,7 +34,7 @@ def entrypoint(project, timeout):
 
     print(f"\nHai selezionato: \n{check_pr_status(project, pr)}")
     if not prompt_utils.ask_confirm("Vuoi continuare il merge?", default=False):
-        sys.exit(0)
+        sys.exit()
 
     branch_name = pr.head.ref
     youtrack_id = youtrack.get_card_from_name(branch_name)
@@ -138,12 +138,17 @@ def check_migrations_merge(pr):
     if git.migrations_found(files_changed):
         logger.warning("ATTENZIONE: migrations rilevate nel codice")
         if not prompt_utils.ask_confirm("Sicuro di voler continuare?"):
-            sys.exit(-1)
+            sys.exit()
 
 
 def check_pr_status(project, pr):
     build_status = CHECKMARK
     reviews = CHECKMARK
+    if pr.mergeable_state == "dirty":
+        logger.error(
+            "La pull request selezionata non è mergeable. Controlla se ci sono conflitti."
+        )
+        sys.exit(-1)
     if pr.mergeable_state == "blocked":
         build_status = pr_build_status(project, pr)
         reviews = pr_reviews(pr)
