@@ -53,8 +53,8 @@ class GithubHandler(metaclass=Singleton):
     def get_link_from_pr(self, repo, pr_number):
         return f"https://github.com/primait/{repo}/pull/{pr_number}"
 
-    def get_commits_since_release(self, repo, release):
-        release_commit = repo.get_commit(release.tag_name)
+    def get_commits_since_release(self, repo, tag):
+        release_commit = repo.get_commit(tag)
         commits = []
         for c in repo.get_commits():
             if c == release_commit:
